#
# spec file for package exa
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           exa
Version:        0.9.0
Release:        bp155.2.50
Summary:        Replacement for ls written in Rust
License:        MIT
Group:          System/Base
Url:            https://the.exa.website/
Source0:        https://github.com/ogham/exa/archive/v%{version}.tar.gz
Source1:        vendor.tar.xz
BuildRequires:  cargo
BuildRequires:  cmake
BuildRequires:  git
BuildRequires:  pkgconfig
BuildRequires:  rust
BuildRequires:  rust
BuildRequires:  pkgconfig(zlib)
ExcludeArch:    %ix86 ppc

%description
exa is a replacement for ls written in Rust.
With similar but not identical options.

%prep
%setup -q
%setup -q -D -T -a 1
mkdir .cargo
cat >.cargo/config <<EOF
[source.crates-io]
registry = 'https://github.com/rust-lang/crates.io-index'
replace-with = 'vendored-sources'
[source.vendored-sources]
directory = './vendor'
EOF

%build
cargo build --release %{?_smp_mflags}

%install
mkdir build
cargo install --path . --root=build
mkdir -p %{buildroot}%{_bindir}
install -Dm0755 build/bin/exa %{buildroot}%{_bindir}/exa

%files
%license LICENCE
%doc README.md
%{_bindir}/exa

%changelog
* Tue Oct  1 2019 Luke Jones <luke@ljones.dev>
- Use the `pwd`/.cargo method of including vendored sources which
  removes the need to export a path for cargo.
* Tue Jul 16 2019 mvetter@suse.com
- Update to 0.9.0:
  Additions:
  * Icon support with --icons (9497b30)
  * New sort options .name and .Name which ignore a leading dot (a156d96)
  * Support TIME_STYLE environment variable (9917810)
  * New option to only display directories, --only-dirs (054cac6)
  * Support 24-bit colours (dc2009a)
  * Display if a file is ignored by Git (80b0d9d)
  Changes:
  * Replace the mi colour with bO overlay colour (59d9e90)
  * Pre-release versions have their build number shown (c7497f3)
  * Add --classify to man page (9c77a95)
  * Highlighting for file types .zst (5fae489), Bazel and Ant (c635031), .ts (e711dbc), .m4v (9b446c0), and .jpf (9916742)
  * Create worker threads only once for performance (8cbde76)
  Fixes:
  * Allow zero-padded numbers in $LS_COLORS (afc9657, ce3f05c)
  * Make non-uppercase README files immediate (d9c9dbe)
  * Highlight README~ as temporary, not immediate (57e4c08)
  * Use more accurate time to fix inconsistent sorting (649744d)
  * Prevent infinite loop with -aaR (e936d7e)
  * Fix panic in certain timezones (9f76f94 and this fix)
  * Fix sorting by created time (faed8f9)
  * Fix Git status not working for paths containing ../ (f1a5b64)
* Mon May 14 2018 bjorn.lie@gmail.com
- Add %%%%ix86 ppc ExcludeArch: Do not even atempt to build for these
  targets.
* Sun Oct 22 2017 luke.nukem.jones@gmail.com
- Update to v0.8.0
- Additions
  + Use completely new, less strict, more friendly options parser (b5bcf22)
  + Add a strict mode, for when you want to check your options (97d1472)
  + Add EXA_GRID_ROWS that makes --long --grid a bit more palatable (e933fa6)
  + Add EXA_DEBUG for logging information (e0727a1)
  + Add LS_COLORS parsing and colouring (adfee28, aa2e3a5)
  + Add EXA_COLORS parsing and colouring, which overrides the above (075fe80, aa2e3a5)
  +Initial support for a --git-ignore flag (827aa8b)
- Changes
  + Default to sorting case-insensitively (57c647f)
  + Hide xattr errors unless xattrs were explicitly asked for (5189d66)
  + Add orf and nef file types (40ce7ba)
  + Add bk file type (eda3e56)
  + Only check the terminal width of stdout, not stdin and stderr (4289f4d)
  + Sorting by date now has new and old convenience aliases (f55bd6d)
  + Use only verified published crates, so exa can be on crates.io (1efb8a5)
- Fixes
  + Use a patched version of libgit2 to prevent that libhttp_parser error (3405db1)
  + Fix bug where --tree --all didn't work (a2cd39e)
  + Fix bug where ISO dates were long when they should be short and vice versa (fca5b6b)
  + Fix bug where month name padding made the whole table look weird (999c9d5)
* Fri Aug  4 2017 mvetter@suse.com
- Create initial package for version 0.7.0
